Struct youtube_transcript::Config
source · pub struct Config { /* private fields */ }Expand description
configuration that contains anchor points for identifying captions from youtube’s html webpage.
pub struct Config { /* private fields */ }configuration that contains anchor points for identifying captions from youtube’s html webpage.