Struct youtube_transcript::TranscriptCore
source · pub struct TranscriptCore {
pub text: String,
pub start: Duration,
pub duration: Duration,
}Expand description
Struct that contains data about transcirpt text along with start and duration in the whole video.
Fields
text: Stringtranscript text. Ex: “Hi How are you”
start: Durationstarting time of the text in the whole video. Ex: “0 sec”
duration: Durationduration of the text Ex: “0.8 sec”